@@ -1,6 +1,5 @@
 """Create a project with venv."""
 import os
-import venv
 import sys
 
 
@@ -19,13 +18,13 @@ def create(pname):
     dirs_folders = [f'{pname}/{pname}', f'{pname}/tests']
 
     current_path = os.getcwd()
-    exist_path = os.path.join(current_path, pname)
+    exist_path = os.path.join(current_path, f'{pname}-venv')
     project_path = os.path.join(exist_path, pname)
     if os.path.exists(exist_path):
         print("Project {} already exists in {}.\n".format(pname, current_path))
         sys.exit()
     else:
-        venv.create(pname)
+        os.system(f'python3 -m venv {pname}-venv')
         os.chdir(exist_path)
         for i in range(len(dirs_folders)):
             os.makedirs(os.path.join(exist_path, dirs_folders[i]))
@@ -37,4 +36,4 @@ def create(pname):
 
         print("\n🎉 Project {} created in {}.\n".format(pname, current_path))
 
-    return project_path
+    return project_path, exist_path
